@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Get XML.
 has xml => (
@@ -129,7 +129,6 @@ For more information about Dnipropetrovsk Map, click L<here|https://en.wikipedia
 
  # Pragmas.
  use strict;
- use utf8;
  use warnings;
 
  # Modules.
@@ -164,7 +163,6 @@ For more information about Dnipropetrovsk Map, click L<here|https://en.wikipedia
  # GraphViz object.
  my $g = Map::Tube::GraphViz->new(
          'callback_node' => \&node_color_without_label,
-         'driver' => 'neato',
          'tube' => $obj,
  );
 
@@ -195,7 +193,9 @@ L<namespace::clean>.
 =head1 SEE ALSO
 
 L<Map::Tube>,
+L<Map::Tube::Graph>,
 L<Map::Tube::GraphViz>,
+L<Map::Tube::Plugin::Graph>,
 L<Map::Tube::Text::Table>,
 L<Task::Map::Tube>.
 
@@ -216,6 +216,7 @@ L<Map::Tube::Novosibirsk>,
 L<Map::Tube::Prague>,
 L<Map::Tube::SaintPetersburg>,
 L<Map::Tube::Samara>,
+L<Map::Tube::Singapore>,
 L<Map::Tube::Sofia>,
 L<Map::Tube::Tbilisi>,
 L<Map::Tube::Tokyo>,
@@ -241,6 +242,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
